"""  Created on 24/01/2024::
------------- haver_maps.py -------------
 
**Authors**: L. Mingarelli
"""

HAVER_COUNTRIES = {code: {'alpha2': a2, 'name': name}
                   for code, a2, name in zip(('512', '914', '612', '859', '171', '614', '312', '311', '213', '911',
                                              '314', '193', '122', '912', '313', '419', '513', '316', '913', '124',
                                              '126', '339', '638', '319', '514', '218', '963', '616', '223', '585',
                                              '889', '371', '516', '918', '748', '618', '522', '622', '156', '624',
                                              '377', '626', '628', '830', '228', '924', '814', '865', '233', '632',
                                              '634', '636', '815', '238', '662', '960', '928', '354', '355', '423',
                                              '935', '934', '128', '611', '321', '243', '938', '537', '248', '023',
                                              '025', '996', '997', '469', '253', '642', '643', '939', '644', '816',
                                              '323', '819', '172', '132', '333', '887', '876', '266', '646', '648',
                                              '488', '915', '134', '652', '823', '174', '326', '328', '329', '829',
                                              '258', '113', '656', '654', '336', '263', '268', '532', '944', '176',
                                              '534', '536', '429', '433', '178', '118', '436', '136', '343', '158',
                                              '165', '439', '916', '664', '826', '542', '967', '443', '917', '544',
                                              '941', '446', '666', '668', '672', '147', '946', '137', '546', '962',
                                              '674', '676', '548', '556', '678', '181', '867', '349', '682', '684',
                                              '920', '273', '868', '921', '183', '948', '943', '351', '686', '688',
                                              '518', '728', '836', '558', '353', '138', '839', '196', '278', '692',
                                              '694', '851', '849', '954', '142', '449', '564', '565', '487', '283',
                                              '356', '853', '288', '459', '293', '566', '863', '964', '182', '359',
                                              '453', '696', '968', '922', '714', '568', '862', '135', '716', '456',
                                              '722', '942', '965', '718', '724', '576', '936', '961', '813', '726',
                                              '199', '184', '524', '379', '363', '856', '361', '362', '357', '352',
                                              '364', '732', '733', '366', '734', '144', '146', '463', '528', '923',
                                              '738', '578', '742', '818', '866', '369', '744', '186', '925', '381',
                                              '869', '373', '746', '926', '466', '112', '111', '877', '298', '870',
                                              '927', '846', '187', '299', '582', '857', '131', '265', '793', '473',
                                              '474', '188', '754', '698'),
                                             ('AF', 'AL', 'DZ', 'AS', 'AD', 'AO', 'AI', 'AG', 'AR', 'AM', 'AW', 'AU',
                                              'AT', 'AZ', 'BS', 'BH', 'BD', 'BB', 'BY', 'BE', 'Not available', 'BZ',
                                              'BJ', 'BM', 'BT', 'BO', 'BA', 'BW', 'BR', 'IO', 'Not available', 'VG',
                                              'BN', 'BG', 'BF', 'BI', 'KH', 'CM', 'CA', 'CV', 'KY', 'CF', 'TD',
                                              'Not available', 'CL', 'CN', 'CX', 'CC', 'CO', 'KM', 'CG', 'CD', 'CK',
                                              'CR', 'CI', 'HR', 'CU', 'CW', 'Not available', 'CY', 'CZ',
                                              'Not available', 'DK', 'DJ', 'DM', 'DO', 'Not available', 'TL', 'EC',
                                              'Not available', 'Not available', 'Not available', 'Not available', 'EG',
                                              'SV', 'GQ', 'ER', 'EE', 'ET', 'FO', 'FK', 'FJ', 'FI', 'FR', 'GF', 'PF',
                                              'TF', 'Not available', 'GA', 'GM', 'Not available', 'GE', 'DE', 'GH',
                                              'GI', 'GR', 'GL', 'GD', 'GP', 'GU', 'GT', 'GG', 'GN', 'GW', 'GY', 'HT',
                                              'HN', 'HK', 'HU', 'IS', 'IN', 'ID', 'IR', 'IQ', 'IE', 'IM', 'IL', 'IT',
                                              'JM', 'JP', 'JE', 'JO', 'KZ', 'KE', 'KI', 'KR', 'Not available', 'KW',
                                              'KG', 'LA', 'LV', 'LB', 'LS', 'LR', 'LY', 'LI', 'LT', 'LU', 'MO', 'MK',
                                              'MG', 'MW', 'MY', 'MV', 'ML', 'MT', 'MH', 'MQ', 'MR', 'MU', 'YT', 'MX',
                                              'FM', 'MD', 'MC', 'MN', 'ME', 'MS', 'MA', 'MZ', 'MM', 'NA', 'NR', 'NP',
                                              'Not available', 'NL', 'NC', 'NZ', 'NI', 'NE', 'NG', 'NU', 'NF', 'KP',
                                              'NO', 'OM', 'PK', 'PW', 'PS', 'PA', 'Not available', 'PG', 'PY', 'YD',
                                              'PE', 'PH', 'PN', 'PL', 'PT', 'PR', 'QA', 'RE', 'RO', 'RU', 'RW',
                                              'Not available', 'WS', 'SM', 'ST', 'SA', 'SN', 'RS', 'Not available',
                                              'SC', 'SL', 'SG', 'SK', 'SI', 'SB', 'SO', 'ZA', 'ES', 'LK', 'BL', 'PM',
                                              'SH', 'KN', 'LC', 'MF', 'SX', 'VC', 'SD', 'SS', 'SR', 'SZ', 'SE', 'CH',
                                              'SY', 'TW', 'TJ', 'TZ', 'TH', 'TG', 'TK', 'TO', 'TT', 'TN', 'TR', 'TM',
                                              'TC', 'TV', 'VI', 'UG', 'UA', 'AE', 'GB', 'US', 'UM', 'UY', 'UM', 'UZ',
                                              'VU', 'Not available', 'VE', 'VN', 'WF', 'Not available', 'Not available',
                                              'EH', 'Not available', 'YE', 'Not available', 'ZM', 'ZW'),
                                             (
                                             'Afghanistan', 'Albania', 'Algeria', 'American Samoa', 'Andorra', 'Angola',
                                             'Anguilla', 'Antigua & Barbuda', 'Argentina', 'Armenia', 'Aruba',
                                             'Australia', 'Austria', 'Azerbaijan', 'Bahamas', 'Bahrain', 'Bangladesh',
                                             'Barbados', 'Belarus', 'Belgium', 'Belgium-Luxembourg', 'Belize', 'Benin',
                                             'Bermuda', 'Bhutan', 'Bolivia', 'Bosnia & Herzegovina', 'Botswana',
                                             'Brazil', 'British Indian Ocean Territory', 'British Overseas Territories',
                                             'British Virgin Islands', 'Brunei', 'Bulgaria', 'Burkina Faso', 'Burundi',
                                             'Cambodia', 'Cameroon', 'Canada', 'Cape Verde', 'Cayman Islands',
                                             'Central African Republic', 'Chad', 'Channel Islands', 'Chile', 'China',
                                             'Christmas Island', 'Cocos (Keeling) Islands', 'Colombia', 'Comoros',
                                             'Congo', 'Congo Democratic Rep.', 'Cook Islands', 'Costa Rica',
                                             'Cote Ivoire', 'Croatia', 'Cuba', 'Curacao', 'Curacao & Sint Maarten',
                                             'Cyprus', 'Czech Republic', 'Czechoslovakia', 'Denmark', 'Djibouti',
                                             'Dominica', 'Dominican Republic', 'East Germany', 'East Timor', 'Ecuador',
                                             'Euro Area Changing Composition', 'Euro Area Fixed Composition',
                                             'European Union Changing Composition', 'European Union Fixed Composition',
                                             'Egypt', 'El Salvador', 'Equatorial Guinea', 'Eritrea', 'Estonia',
                                             'Ethiopia', 'Faeroe Islands', 'Falkland Islands', 'Fiji', 'Finland',
                                             'France', 'French Guiana', 'French Polynesia',
                                             'French Southern Territories', 'French West Indies', 'Gabon', 'Gambia',
                                             'West Bank and Gaza Strip', 'Georgia', 'Germany', 'Ghana', 'Gibraltar',
                                             'Greece', 'Greenland', 'Grenada', 'Guadeloupe', 'Guam', 'Guatemala',
                                             'Guernsey', 'Guinea', 'Guinea-Bissau', 'Guyana', 'Haiti', 'Honduras',
                                             'Hong Kong', 'Hungary', 'Iceland', 'India', 'Indonesia', 'Iran', 'Iraq',
                                             'Ireland', 'Isle of Man', 'Israel', 'Italy', 'Jamaica', 'Japan', 'Jersey',
                                             'Jordan', 'Kazakhstan', 'Kenya', 'Kiribati', 'Korea', 'Kosovo', 'Kuwait',
                                             'Kyrgyz Republic', 'Lao P.D.R.', 'Latvia', 'Lebanon', 'Lesotho', 'Liberia',
                                             'Libya', 'Liechtenstein', 'Lithuania', 'Luxembourg', 'Macao',
                                             'Macedonia, FYR', 'Madagascar', 'Malawi', 'Malaysia', 'Maldives', 'Mali',
                                             'Malta', 'Marshall Islands', 'Martinique', 'Mauritania', 'Mauritius',
                                             'Mayotte', 'Mexico', 'Micronesia', 'Moldova', 'Monaco', 'Mongolia',
                                             'Montenegro', 'Montserrat', 'Morocco', 'Mozambique', 'Myanmar', 'Namibia',
                                             'Nauru', 'Nepal', 'Netherlands Antilles', 'Netherlands', 'New Caledonia',
                                             'New Zealand', 'Nicaragua', 'Niger', 'Nigeria', 'Niue', 'Norfolk Island',
                                             'North Korea', 'Norway', 'Oman', 'Pakistan', 'Palau',
                                             'Palestinian Territories', 'Panama', 'Panama Canal Zone',
                                             'Papua New Guinea', 'Paraguay', 'PDR Yemen', 'Peru', 'Philippines',
                                             'Pitcairn', 'Poland', 'Portugal', 'Puerto Rico', 'Qatar', 'Reunion',
                                             'Romania', 'Russia', 'Rwanda', 'Ryukyus', 'Samoa/W. Samoa', 'San Marino',
                                             'Sao Tome & Principe', 'Saudi Arabia', 'Senegal', 'Serbia',
                                             'Serbia and Montenegro', 'Seychelles', 'Sierra Leone', 'Singapore',
                                             'Slovakia/Slovak Republic', 'Slovenia', 'Solomon Islands', 'Somalia',
                                             'South Africa', 'Spain', 'Sri Lanka', 'St. Barts', 'St Pierre & Miquelon',
                                             'St. Helena', 'St. Kitts & Nevis', 'St. Lucia', 'St. Martin (French Part)',
                                             'Sint Maarten (Dutch Part)', 'St. Vincent and the Grenadines', 'Sudan',
                                             'South Sudan', 'Suriname', 'Swaziland', 'Sweden', 'Switzerland',
                                             'Syrian Arab Republic', 'Taiwan', 'Tajikistan', 'Tanzania', 'Thailand',
                                             'Togo', 'Tokelau', 'Tonga', 'Trinidad & Tobago', 'Tunisia', 'Turkey',
                                             'Turkmenistan', 'Turks and Caicos Islands', 'Tuvalu',
                                             'U.S. Virgin Islands', 'Uganda', 'Ukraine', 'United Arab Emirates',
                                             'United Kingdom', 'United States', 'United States Minor Outlying Islands',
                                             'Uruguay',
                                             'US Pacific Islands', 'Uzbekistan', 'Vanuatu', 'Vatican', 'Venezuela',
                                             'Vietnam', 'Wallis and Futuna', 'West Germany', 'West Indies UK',
                                             'Western Sahara', 'Yemen Arab Rep', 'Yemen, Rep of', 'Yugoslavia',
                                             'Zambia', 'Zimbabwe'))
                   }

